You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by ta...@apache.org on 2013/11/27 18:31:05 UTC

svn commit: r1546128 - in /activemq/activemq-dotnet/Apache.NMS.MQTT/trunk: ./ src/main/csharp/ src/main/csharp/Commands/ src/test/csharp/

Author: tabish
Date: Wed Nov 27 17:31:04 2013
New Revision: 1546128

URL: http://svn.apache.org/r1546128
Log:
https://issues.apache.org/jira/browse/AMQNET-458

Implementation

Modified:
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/DISCONNECT.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGREQ.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGRESP.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/CommonAssemblyInfo.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/ConnectionFactory.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/CommonAssemblyInfo.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/NMSConnectionFactoryTest.cs
    activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/vs2008-mqtt.csproj

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/DISCONNECT.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/DISCONNECT.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/DISCONNECT.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/DISCONNECT.cs Wed Nov 27 17:31:04 2013
@@ -43,6 +43,16 @@ namespace Apache.NMS.MQTT.Commands
 		{
 			get { return true; }
 		}
+
+        public override void Encode(BinaryWriter writer)
+        {
+            // This command has no body. 
+        }
+
+        public override void Decode(BinaryReader reader)
+        {
+            // This command has no body. 
+        }
 	}
 }
 

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGREQ.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGREQ.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGREQ.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGREQ.cs Wed Nov 27 17:31:04 2013
@@ -43,6 +43,16 @@ namespace Apache.NMS.MQTT.Commands
 		{
 			get { return true; }
 		}
+
+        public override void Encode(BinaryWriter writer)
+        {
+            // This command has no body. 
+        }
+
+        public override void Decode(BinaryReader reader)
+        {
+            // This command has no body. 
+        }
 	}
 }
 

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGRESP.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGRESP.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGRESP.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/Commands/PINGRESP.cs Wed Nov 27 17:31:04 2013
@@ -43,6 +43,16 @@ namespace Apache.NMS.MQTT.Commands
 		{
 			get { return true; }
 		}
+
+        public override void Encode(BinaryWriter writer)
+        {
+            // This command has no body. 
+        }
+
+        public override void Decode(BinaryReader reader)
+        {
+            // This command has no body. 
+        }
 	}
 }
 

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/CommonAssemblyInfo.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/CommonAssemblyInfo.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/CommonAssemblyInfo.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/CommonAssemblyInfo.cs Wed Nov 27 17:31:04 2013
@@ -22,6 +22,6 @@ using System.Runtime.InteropServices;
 [assembly: AssemblyCopyrightAttribute("Copyright (C) 2005-2013 Apache Software Foundation")]
 [assembly: AssemblyTrademarkAttribute("")]
 [assembly: AssemblyCultureAttribute("")]
-[assembly: AssemblyVersionAttribute("1.7.0.3251")]
+[assembly: AssemblyVersionAttribute("1.7.0.3252")]
 [assembly: AssemblyInformationalVersionAttribute("1.7.0")]
 

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/ConnectionFactory.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/ConnectionFactory.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/ConnectionFactory.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/main/csharp/ConnectionFactory.cs Wed Nov 27 17:31:04 2013
@@ -152,7 +152,7 @@ namespace Apache.NMS.MQTT
             get { return brokerUri; }
             set
             {
-                brokerUri = new Uri(URISupport.StripPrefix(value.OriginalString, "stomp:"));
+                brokerUri = new Uri(URISupport.StripPrefix(value.OriginalString, "mqtt:"));
 
                 if(!String.IsNullOrEmpty(brokerUri.Query) && !brokerUri.OriginalString.EndsWith(")"))
                 {

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/CommonAssemblyInfo.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/CommonAssemblyInfo.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/CommonAssemblyInfo.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/CommonAssemblyInfo.cs Wed Nov 27 17:31:04 2013
@@ -22,6 +22,6 @@ using System.Runtime.InteropServices;
 [assembly: AssemblyCopyrightAttribute("Copyright (C) 2005-2013 Apache Software Foundation")]
 [assembly: AssemblyTrademarkAttribute("")]
 [assembly: AssemblyCultureAttribute("")]
-[assembly: AssemblyVersionAttribute("1.7.0.3251")]
+[assembly: AssemblyVersionAttribute("1.7.0.3252")]
 [assembly: AssemblyInformationalVersionAttribute("1.7.0")]
 

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/NMSConnectionFactoryTest.cs
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/NMSConnectionFactoryTest.cs?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/vs2008-mqtt.csproj (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/vs2008-mqtt.csproj Wed Nov 27 17:31:04 2013
@@ -117,5 +117,7 @@
     <None Include="NOTICE.txt" />
     <None Include="README.txt" />
     <None Include="keyfile\NMSKey.snk" />
+    <None Include="nant.build" />
+    <None Include="nant-common.xml" />
   </ItemGroup>
 </Project>
\ No newline at end of file
--- activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/NMSConnectionFactoryTest.cs (original)
+++ activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/src/test/csharp/NMSConnectionFactoryTest.cs Wed Nov 27 17:31:04 2013
@@ -25,24 +25,24 @@ namespace Apache.NMS.MQTT.Test
     [TestFixture]
     public class NMSConnectionFactoryTest
     {
-//      [Test]
-//      [TestCase("mqtt:tcp://${activemqhost}:61613")]
+        [Test]
+        [TestCase("mqtt:tcp://${activemqhost}:1883")]
 //      [TestCase("stomp:failover:(tcp://${activemqhost}:61616?keepAlive=false&wireFormat.maxInactivityDuration=1000)")]
 //      [TestCase("stomp:failover:(tcp://${activemqhost}:61616?keepAlive=false&wireFormat.maxInactivityDuration=1000)?connection.asyncSend=false")]
 //		[TestCase("stomp:tcp://${activemqhost}:61613?connection.asyncsend=false")]
 //		[TestCase("stomp:tcp://${activemqhost}:61613?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:tcp://${activemqhost}:61613?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:(tcp://${activemqhost}:61613)?connection.asyncSend=false", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:tcp://InvalidHost:61613", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:tcp://InvalidHost:61613", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:tcp://InvalidHost:61613?connection.asyncsend=false", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("ftp://${activemqhost}:61613", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("http://${activemqhost}:61613", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("discovery://${activemqhost}:6155", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("sms://${activemqhost}:61613", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("sms://${activemqhost}:1883", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("stomp:multicast://${activemqhost}:6155", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("(tcp://${activemqhost}:61613,tcp://${activemqhost}:61613)", ExpectedException = typeof(UriFormatException))]
-//		[TestCase("tcp://${activemqhost}:61613,tcp://${activemqhost}:61613", ExpectedException = typeof(UriFormatException))]
+//		[TestCase("(tcp://${activemqhost}:1883,tcp://${activemqhost}:1883)", ExpectedException = typeof(UriFormatException))]
+//		[TestCase("tcp://${activemqhost}:1883,tcp://${activemqhost}:1883", ExpectedException = typeof(UriFormatException))]
         public void TestURI(string connectionURI)
         {
             NMSConnectionFactory factory = new NMSConnectionFactory(
@@ -25,24 +25,24 @@ namespace Apache.NMS.MQTT.Test
 //      [TestCase("stomp:failover:(tcp://${activemqhost}:61616?keepAlive=false&wireFormat.maxInactivityDuration=1000)")]
 //      [TestCase("stomp:failover:(tcp://${activemqhost}:61616?keepAlive=false&wireFormat.maxInactivityDuration=1000)?connection.asyncSend=false")]
-//		[TestCase("stomp:tcp://${activemqhost}:61613?connection.asyncsend=false")]
-//		[TestCase("stomp:tcp://${activemqhost}:61613?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("stomp:tcp://${activemqhost}:61613?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("stomp:(tcp://${activemqhost}:61613)?connection.asyncSend=false", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("stomp:tcp://InvalidHost:61613", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("stomp:tcp://InvalidHost:61613", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("stomp:tcp://InvalidHost:61613?connection.asyncsend=false", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("ftp://${activemqhost}:61613", ExpectedException = typeof(NMSConnectionException))]
-//		[TestCase("http://${activemqhost}:61613", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:tcp://${activemqhost}:1883?connection.asyncsend=false")]
+//		[TestCase("stomp:tcp://${activemqhost}:1883?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:tcp://${activemqhost}:1883?connection.InvalidParameter=true", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:(tcp://${activemqhost}:1883)?connection.asyncSend=false", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:tcp://InvalidHost:1883", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:tcp://InvalidHost:1883", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("stomp:tcp://InvalidHost:1883?connection.asyncsend=false", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("ftp://${activemqhost}:1883", ExpectedException = typeof(NMSConnectionException))]
+//		[TestCase("http://${activemqhost}:1883", ExpectedException = typeof(NMSConnectionException))]
 //		[TestCase("discovery://${activemqhost}:6155", ExpectedException = typeof(NMSConnectionException))]

Modified: activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/vs2008-mqtt.csproj
URL: http://svn.apache.org/viewvc/activemq/activemq-dotnet/Apache.NMS.MQTT/trunk/vs2008-mqtt.csproj?rev=1546128&r1=1546127&r2=1546128&view=diff
==============================================================================